@@ -32,6 +32,7 @@
 
 const struct interface *interfaces[] = {
 	&audio_if,
+	&sco_if,
 	&bluetooth_if,
 	&av_if,
 	&rc_if,
@@ -41,6 +42,7 @@ const struct interface *interfaces[] = {
 	&hf_if,
 	&hh_if,
 	&pan_if,
+	&hl_if,
 	&sock_if,
 	NULL
 };
@@ -254,12 +256,12 @@ static int command_line_to_argv(char *line_buffer, char *argv[], int argv_size)
 
 static void process_line(char *line_buffer)
 {
-	char *argv[10];
+	char *argv[50];
 	int argc;
 	int i = 0;
 	struct method *m;
 
-	argc = command_line_to_argv(line_buffer, argv, 10);
+	argc = command_line_to_argv(line_buffer, argv, 50);
 	if (argc < 1)
 		return;
 
@@ -393,10 +395,12 @@ static void init(void)
 	const struct method *m;
 	const char *argv[4];
 	char init_audio[] = "audio init";
+	char init_sco[] = "sco init";
 	char init_bt[] = "bluetooth init";
 	uint32_t i;
 
 	process_line(init_audio);
+	process_line(init_sco);
 	process_line(init_bt);
 
 	m = get_interface_method("bluetooth", "get_profile_interface");
